@@ -32,7 +32,7 @@
 #include <PointerType.h>
 #include <Modifiers/Topology.h>
 #include <DataStructureBackendManager.h>
-#include <DataStructurePluginInterface.h>
+#include <DataStructureBackendInterface.h>
 
 static const KAboutData pluginAboutData("rocs_rocsgraphfileformat",
                                         0,
@@ -76,7 +76,7 @@ void RocsGraphFileFormatPlugin::readFile()
     // This is a kind of a hack and should be solved better:
     // Document has no setter for the current plugin but on creation it gets created
     // with the plugin that is currently set as DataStructureBackendManager::actualPlugin.
-    DataStructureBackendManager::self()->activeBackend();
+    DataStructureBackendManager::self().activeBackend();
     Document* document = new Document("Untitled");
 
     QFile fileHandle(file().toLocalFile());
@@ -102,11 +102,7 @@ void RocsGraphFileFormatPlugin::readFile()
 
             QString dataLine = in.readLine().simplified();
             while (!in.atEnd() && !dataLine.isEmpty()) {
-                /**/ if (dataLine.startsWith(QLatin1String("top :")))      document->setTop(dataLine.section(' ', 2).toInt());
-                else if (dataLine.startsWith(QLatin1String("bottom :")))   document->setBottom(dataLine.section(' ', 2).toInt());
-                else if (dataLine.startsWith(QLatin1String("left :")))     document->setLeft(dataLine.section(' ', 2).toInt());
-                else if (dataLine.startsWith(QLatin1String("right :")))    document->setRight(dataLine.section(' ', 2).toInt());
-                else if (dataLine.startsWith(QLatin1String("DataStructurePlugin :"))) {
+                if (dataLine.startsWith(QLatin1String("DataStructurePlugin :"))) {
                     // set plugin by unique plugin identifier
                     QString pluginIdentifier = dataLine.section(' ', 2);
                     document->setBackend(pluginIdentifier);
@@ -228,10 +224,10 @@ void RocsGraphFileFormatPlugin::readFile()
                 dataLine = in.readLine().simplified();
             }
             if (document->dataTypeList().contains(type)) {
-                tmpData = tmpDataStructure->addData(name, type);
+                tmpData = tmpDataStructure->createData(name, type);
             } else {
                 kDebug() << "Create data element of type 0, since type " << type << " was not registered.";
-                tmpData = tmpDataStructure->addData(name, 0);
+                tmpData = tmpDataStructure->createData(name, 0);
             }
             if (tmpData) {
                 tmpData->setColor(color);
@@ -267,10 +263,10 @@ void RocsGraphFileFormatPlugin::readFile()
                 dataLine = in.readLine().simplified();
             }
             if (document->pointerTypeList().contains(type)) {
-                tmpPointer = tmpDataStructure->addPointer(dataMap[nameFrom.toInt()],dataMap[nameTo.toInt()], type);
+                tmpPointer = tmpDataStructure->createPointer(dataMap[nameFrom.toInt()],dataMap[nameTo.toInt()], type);
             } else {
                 kDebug() << "Create pointer of type 0, since type " << type << " was not registered.";
-                tmpPointer = tmpDataStructure->addPointer(dataMap[nameFrom.toInt()],dataMap[nameTo.toInt()], 0);
+                tmpPointer = tmpDataStructure->createPointer(dataMap[nameFrom.toInt()],dataMap[nameTo.toInt()], 0);
             }
             if (tmpPointer) {
                 tmpPointer->setWidth(width);
@@ -326,11 +322,7 @@ QString RocsGraphFileFormatPlugin::serialize(const Document &document)
     d->_buffer.clear();
 
     d->_buffer = QString("[Document Properties] \n")
-              % QString("top : ") % QString::number(document.top()) % QChar('\n')
-              % QString("bottom : ") % QString::number(document.bottom()) % QChar('\n')
-              % QString("left : ") % QString::number(document.left()) % QChar('\n')
-              % QString("right : ") % QString::number(document.right()) % QChar('\n')
-              % QString("DataStructurePlugin : ") % DataStructureBackendManager::self()->activeBackend()->internalName() % QChar('\n')
+              % QString("DataStructurePlugin : ") % DataStructureBackendManager::self().activeBackend()->internalName() % QChar('\n')
               % QChar('\n');
 
     foreach(int dataTypeIdentifier, document.dataTypeList()) {
