@@ -20,6 +20,8 @@
 #include "PointerType.h"
 #include "DataStructure.h"
 #include "Pointer.h"
+
+#include <KLocale>
 #include <KDebug>
 #include <boost/weak_ptr.hpp>
 
@@ -53,7 +55,7 @@ public:
     bool _valueVisibility;
     bool _nameVisibility;
     bool _visibility;
-    Document* _document;
+    Document *_document;
 };
 
 
@@ -208,6 +210,17 @@ void PointerType::setPropertyVisible(const QString& name, bool visible)
     emit propertyVisibilityChanged(name);
 }
 
+bool PointerType::isVisible() const
+{
+    return d->_visibility;
+}
+
+void PointerType::setVisible(bool visible)
+{
+    d->_visibility = visible;
+    emit(visibilityChanged(visible));
+}
+
 void PointerType::remove()
 {
     emit removed();
