@@ -96,23 +96,7 @@ bool SelectMoveHandAction::executeMove(QPointF pos)
         return false;
     }
 
-    if (!DocumentManager::self().activeDocument()->isPointAtDocument(pos)) {
-        Document *d = DocumentManager::self().activeDocument();
-        if (pos.x() < d->left()) {
-            pos.setX(d->left());
-        }
-        if (pos.x() > d->right()) {
-            pos.setX(d->right());
-        }
-        if (pos.y() < d->top()) {
-            pos.setY(d->top());
-        }
-        if (pos.y() > d->bottom()) {
-            pos.setY(d->bottom());
-        }
-    }
-
-    foreach(QGraphicsItem * item, _graphScene->selectedItems()) {
+    foreach(QGraphicsItem *item, _graphScene->selectedItems()) {
         if (DataItem *dItem = qgraphicsitem_cast<DataItem*>(item)) {
             dItem->data() -> setPos(pos.x() - _deltas.value(dItem).x(),
                                     pos.y() - _deltas.value(dItem).y());
