@@ -1,7 +1,7 @@
 /*
     This file is part of Rocs,
     Copyright 2004-2011  Tomaz Canabrava <tomaz.canabrava@gmail.com>
-    Copyright 2011-2012  Andreas Cord-Landwehr <cola@uni-paderborn.de>
+    Copyright 2011-2013  Andreas Cord-Landwehr <cola@uni-paderborn.de>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -38,6 +38,7 @@
 #include "Actions/DeleteAction.h"
 #include "Actions/PropertiesDialogAction.h"
 #include "Actions/ZoomAction.h"
+#include <GraphVisualEditor.h>
 
 #include <QGraphicsItem>
 #include <QGraphicsSceneMouseEvent>
@@ -50,52 +51,12 @@
 #include <KDebug>
 
 
-GraphScene::GraphScene(QObject *parent) :
-    QGraphicsScene(parent)
+GraphScene::GraphScene(QObject *parent)
+    : QGraphicsScene(parent)
+    , _graphDocument(0)
+    , _action(0)
+    , _zoomFactor(1)
 {
-    _graphDocument = 0;
-    _hideEdges = false;
-    _action = 0;
-    _minHeight = 0;
-    _minWidth = 0;
-    _zoomFactor = 1;
-
-    // first scene resize will resize to actual whiteboard size
-    setSceneRect(0, 0, 0, 0);
-}
-
-void GraphScene::updateMinSize(qreal minWidth, qreal minHeight)
-{
-    _minWidth = minWidth;
-    _minHeight = minHeight;
-    setSceneRect(-minWidth / 2, -minHeight / 2, minWidth / 2, minHeight / 2);
-
-    Document *gd = DocumentManager::self().activeDocument();
-    if (gd->width() < _minWidth) {
-        gd->setLeft(gd->left() - (_minWidth - gd->width()) / 2);
-        gd->setRight(gd->right() + (_minWidth - gd->width()) / 2);
-    }
-    if (gd->height() < _minHeight) {
-        gd->setTop(gd->top() - (_minHeight - gd->height()) / 2);
-        gd->setBottom(gd->bottom() + (_minHeight - gd->height()) / 2);
-    }
-    gd->changeMinimalSize(minWidth, minHeight);
-    resize();
-}
-
-bool GraphScene::hideEdges()
-{
-    return _hideEdges;
-}
-
-void GraphScene::setHideEdges(bool h)
-{
-    _hideEdges = h;
-    if (! _hideEdges) {
-        foreach(QGraphicsItem * i, _hidedEdges) {
-            i->update();
-        }
-    }
 }
 
 void GraphScene::setActiveGraph(DataStructurePtr g)
@@ -105,12 +66,6 @@ void GraphScene::setActiveGraph(DataStructurePtr g)
     connect( _graph.get(), SIGNAL(changed()), this, SLOT(update()), Qt::UniqueConnection);
 }
 
-void GraphScene::updateAfter(QGraphicsItem *item)
-{
-    if (_hidedEdges.contains(item)) return;
-    _hidedEdges << item;
-}
-
 void GraphScene::setAction(QAction *action)
 {
     if (_action) {
@@ -124,37 +79,28 @@ void GraphScene::setAction(QAction *action)
 void GraphScene::setActiveDocument()
 {
     kDebug() << "Setting the document in the scene";
-    Document *gd = DocumentManager::self().activeDocument();
-    if (_graphDocument == gd) {
+    Document *document = DocumentManager::self().activeDocument();
+    if (_graphDocument == document) {
         return;
-    } else if (gd == 0) {
+    } else if (document == 0) {
         releaseDocument();
         return;
     }
 
-    // adapt document to scene if too small
-    _graphDocument = gd;
-    if (gd->width() < _minWidth) {
-        gd->setLeft(gd->left() - (_minWidth - gd->width()) / 2);
-        gd->setRight(gd->right() + (_minWidth - gd->width()) / 2);
-    }
-    if (gd->height() < _minHeight) {
-        gd->setTop(gd->top() - (_minHeight - gd->height()) / 2);
-        gd->setBottom(gd->bottom() + (_minHeight - gd->height()) / 2);
-    }
-
+    // set document
+    _graphDocument = document;
     resize();
 
-    int size = gd->dataStructures().size();
+    int size = document->dataStructures().size();
     for (int i = 0; i < size; i++) {
-        updateGraph(gd->dataStructures().at(i));
-        connectGraphSignals(gd->dataStructures().at(i));
+        updateGraph(document->dataStructures().at(i));
+        connectGraphSignals(document->dataStructures().at(i));
     }
 
-    connect(gd, SIGNAL(dataStructureCreated(DataStructurePtr)),
+    connect(document, SIGNAL(dataStructureCreated(DataStructurePtr)),
             this, SLOT(connectGraphSignals(DataStructurePtr)));
-
-    connect(gd, SIGNAL(resized()), this, SLOT(resize()));
+    connect(document, SIGNAL(sceneRectChanged(QRectF)),
+            this, SLOT(resize()));
 
     createItems();
 }
@@ -192,17 +138,17 @@ void GraphScene::releaseDocument()
     }
 }
 
-QGraphicsItem *GraphScene::createData(DataPtr n)
+QGraphicsItem * GraphScene::createData(DataPtr n)
 {
-    DataItem *nItem = (DataItem*)(DataStructureBackendManager::self()->dataItem(n));
+    DataItem *nItem = (DataItem*)(DataStructureBackendManager::self().dataItem(n));
     addItem(nItem);
     addItem(nItem->propertyListItem());
     return nItem;
 }
 
-QGraphicsItem *GraphScene::createEdge(PointerPtr e)
+QGraphicsItem * GraphScene::createEdge(PointerPtr e)
 {
-    PointerItem *pointerItem = (PointerItem*)DataStructureBackendManager::self()->pointerItem(e);
+    PointerItem *pointerItem = (PointerItem*)DataStructureBackendManager::self().pointerItem(e);
     addItem(pointerItem);
     addItem(pointerItem->propertyListItem());
     return pointerItem;
@@ -245,7 +191,7 @@ void GraphScene::mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent)
     QGraphicsScene::mousePressEvent(mouseEvent);
 }
 
-void  GraphScene::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *mouseEvent)
+void GraphScene::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *mouseEvent)
 {
     if (mouseEvent->button() == Qt::LeftButton) {
         QGraphicsItem *i = itemAt(mouseEvent->scenePos());
@@ -270,16 +216,16 @@ void GraphScene::mouseReleaseEvent(QGraphicsSceneMouseEvent *mouseEvent)
 void GraphScene::keyPressEvent(QKeyEvent *keyEvent)
 {
     keyEvent->accept();
-    emit(keyPressed(keyEvent));
+    emit keyPressed(keyEvent);
 }
 
 void GraphScene::keyReleaseEvent(QKeyEvent *keyEvent)
 {
     keyEvent->accept();
-    emit(keyReleased(keyEvent));
+    emit keyReleased(keyEvent);
 }
 
-void GraphScene::contextMenuEvent(QGraphicsSceneContextMenuEvent* event)
+void GraphScene::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 {
     event->accept();
     _contextMenu = createContextMenu(event->scenePos(), event->screenPos());
@@ -289,12 +235,13 @@ void GraphScene::contextMenuEvent(QGraphicsSceneContextMenuEvent* event)
 
 void GraphScene::updateGraph(DataStructurePtr g)
 {
-    //FIXME this is a workaround to trigger updates
-    foreach(DataPtr n, g->dataList()) {
+    //TODO this is a workaround to trigger updates
+    DataList dataList = g->dataListAll();
+    foreach(DataPtr n, dataList) {
         n->setColor(n->color());
     }
-
-    foreach(PointerPtr e, g->pointers()) {
+    PointerList pointerList = g->pointerListAll();
+    foreach(PointerPtr e, pointerList) {
         e->setWidth(e->width());
     }
 }
@@ -315,16 +262,34 @@ void GraphScene::updateDocument()
 
 void GraphScene::resize()
 {
-    QRectF newSize(_graphDocument->left(), // x
-                   _graphDocument->top(),  // y
-                   _graphDocument->right() - _graphDocument->left(), // width
-                   _graphDocument->bottom() - _graphDocument->top()); // height
+    if (!_graphDocument) {
+        return;
+    }
 
-    setSceneRect(newSize);
+    // set scene rect according to visual editor rect
+    QRectF graphRect = _graphDocument->sceneRect();
+    QRectF editorRect = GraphVisualEditor::self()->rect();
+
+    QRectF sceneRect = graphRect;
+    sceneRect.adjust(-200, -200, 200, 200); // increase whiteboard in each direction around data elements
+    if (editorRect.left() < sceneRect.left()) {
+        sceneRect.setLeft(editorRect.left());
+    }
+    if (editorRect.right() > sceneRect.right()) {
+        sceneRect.setRight(editorRect.right());
+    }
+    if (editorRect.top() < sceneRect.top()) {
+        sceneRect.setTop(editorRect.top());
+    }
+    if (editorRect.bottom() > sceneRect.bottom()) {
+        sceneRect.setBottom(editorRect.bottom());
+    }
+
+    setSceneRect(sceneRect);
     emit resized();
 }
 
-qreal GraphScene::zoomFactor()
+qreal GraphScene::zoomFactor() const
 {
     return _zoomFactor;
 }
@@ -350,7 +315,7 @@ void GraphScene::zoomTo(qreal scaleFactor)
     emit zoomFactorChanged(_zoomFactor);
 }
 
-void GraphScene::zoomToRect(QRectF rect)
+void GraphScene::zoomToRect(const QRectF &rect)
 {
     views().at(0)->fitInView(rect, Qt::KeepAspectRatioByExpanding);
     //FIXME add computation for new zoomfactor!
@@ -363,13 +328,13 @@ void GraphScene::resetZoom()
     views().at(0)->resetMatrix();
 }
 
-void GraphScene::centerOn(QPointF pos)
+void GraphScene::centerOn(const QPointF &pos)
 {
     views().at(0)->centerOn(pos);
 }
 
 
-QMenu* GraphScene::createContextMenu(QPointF scenePosition, QPointF screenPosition)
+QMenu * GraphScene::createContextMenu(const QPointF &scenePosition, const QPointF &screenPosition)
 {
     QMenu *menu = new QMenu; // the context menu
     QMenu *menuDataStructure = menu->addMenu(i18nc("@title:menu", "Data Structure"));
@@ -418,13 +383,14 @@ QMenu* GraphScene::createContextMenu(QPointF scenePosition, QPointF screenPositi
     AlignAction *alignDataStructureTree   = new AlignAction(i18nc("@action:inmenu align elements such that crossing edges are minimized", "Minimize Crossing Edges"), AlignAction::MinCutTree, this);
 
     if (contextDataStructure) {
-        alignDataStructureBottom->registerData(contextDataStructure->dataList());
-        alignDataStructureCenter->registerData(contextDataStructure->dataList());
-        alignDataStructureTop->registerData(contextDataStructure->dataList());
-        alignDataStructureLeft->registerData(contextDataStructure->dataList());
-        alignDataStructureRight->registerData(contextDataStructure->dataList());
-        alignDataStructureCircle->registerData(contextDataStructure->dataList());
-        alignDataStructureTree->registerData(contextDataStructure->dataList());
+        //FIXME only default data type considered
+        alignDataStructureBottom->registerData(contextDataStructure->dataList(0));
+        alignDataStructureCenter->registerData(contextDataStructure->dataList(0));
+        alignDataStructureTop->registerData(contextDataStructure->dataList(0));
+        alignDataStructureLeft->registerData(contextDataStructure->dataList(0));
+        alignDataStructureRight->registerData(contextDataStructure->dataList(0));
+        alignDataStructureCircle->registerData(contextDataStructure->dataList(0));
+        alignDataStructureTree->registerData(contextDataStructure->dataList(0));
     }
     if (contextAtItem) {
         PropertiesDialogAction *dataStructurePropertiesAction = new PropertiesDialogAction(i18nc("@action:inmenu", "Properties"), contextDataStructure, this);
